@@ -11,6 +11,10 @@ def is_available():
     return comm_pipe_out is not None
 
 
+def is_first_execution():
+    return retrieved_checkpoint is None
+
+
 class checkpoint:
     def __init__(self):
         self._linked_files = []
@@ -34,7 +38,7 @@ class checkpoint:
         return None
 
 
-def restore_checkpoint():
+def _restore_checkpoint():
     if not os.path.exists('/tmp/__hydra_checkpoint.json'):
         return None
     with open('/tmp/__hydra_checkpoint.json') as json_file:
@@ -44,7 +48,26 @@ def restore_checkpoint():
         return ck
 
 
+retrieved_checkpoint = _restore_checkpoint()
+
+
+def restore_checkpoint():
+    return retrieved_checkpoint
+
+
 def set_eta(eta):
     comm_pipe_out.write(json.dumps({'_request_type': 'set_eta', 'millisec': int(eta * 1000)}))
     comm_pipe_out.write('\0')
     comm_pipe_out.flush()
+
+
+def save_output(obj, name=None):
+    req = {
+        '_request_type': 'produced_output',
+        'data': obj
+    }
+    if name:
+        req['name'] = name
+    comm_pipe_out.write(json.dumps(req, default=lambda o: o.__dict__))
+    comm_pipe_out.write('\0')
+    comm_pipe_out.flush()
